@@ -141,6 +141,14 @@ class StationDataLoader:
         tmaxs, tmins = parse_station_temps_as_dict(self.csv_text, use_fahrenheit)
         return {"highs": tmaxs, "lows": tmins}
 
+    def get_cumulative_snow_water_equivalent(self, use_inches=True):
+        """
+        cumulative snow water equivalent is the amount of snow on the ground
+        in water equivalent. Persists across days.
+        """
+        self.populate_csv()
+        return parse_station_cswe_as_dict(self.csv_text, use_inches)
+
     def get_snow_depth(self, use_inches=True):
         """
         Snow depth is the total amount of snow on the ground at the time
