@@ -44,3 +44,11 @@ def test_get_full_rtma_history():
     time_diff = last_date - first_date
     time_diff_hours = time_diff.days * 24 + time_diff.seconds // 3600
     assert time_diff_hours == len(res[1])
+
+def test_get_era5_dict():
+    lat, lon = 35.70284883765463, -81.29880863239713
+    res = http_client.get_era5_dict(lat, lon, 'era5_land_wind_u-hourly')
+    first_time, last_time = sorted(res[1])[0], sorted(res[1])[-1]
+    time_diff = last_time - first_time
+    time_diff_hours = time_diff.days * 24 + time_diff.seconds // 3600
+    assert time_diff_hours + 1 == len(res[1])
